@@ -2,8 +2,8 @@
 #'
 #' Kernel-Weighted Unsupervised Discriminant Projection (KUDP) is a generalization of UDP where
 #' proximity is given by weighted values via heat kernel,
-#' \deqn{K_{i,j} = \exp(-\|x_i-x_j\|^2/kbandwidth)}
-#' whence UDP uses binary connectivity. If \code{kbandwidth} is \eqn{+\infty}, it becomes
+#' \deqn{K_{i,j} = \exp(-\|x_i-x_j\|^2/bandwidth)}
+#' whence UDP uses binary connectivity. If \code{bandwidth} is \eqn{+\infty}, it becomes
 #' a standard UDP problem. Like UDP, it also performs PCA preprocessing for rank-deficient case.
 #'
 #' @param X an \eqn{(n\times p)} matrix or data frame whose rows are observations
@@ -14,9 +14,8 @@
 #'  Default is \code{c("proportion",0.1)}, connecting about 1/10 of nearest data points
 #'  among all data points. See also \code{\link{aux.graphnbd}} for more details.
 #' @param preprocess an additional option for preprocessing the data.
-#' Default is "center" and two other options "decorrelate" and "whiten"
-#' are supported. See also \code{\link{aux.preprocess}} for more details.
-#' @param kbandwidth bandwidth parameter for heat kernel as the equation above.
+#' Default is "center". See also \code{\link{aux.preprocess}} for more details.
+#' @param bandwidth bandwidth parameter for heat kernel as the equation above.
 #'
 #' @return a named list containing
 #' \describe{
@@ -32,9 +31,9 @@
 #' X = aux.gensamples(n=200)
 #'
 #' ## use different kernel bandwidth
-#' out1 <- do.kudp(X, kbandwidth=0.1)
-#' out2 <- do.kudp(X, kbandwidth=10)
-#' out3 <- do.kudp(X, kbandwidth=1000)
+#' out1 <- do.kudp(X, bandwidth=0.1)
+#' out2 <- do.kudp(X, bandwidth=10)
+#' out3 <- do.kudp(X, bandwidth=1000)
 #'
 #' ## visualize
 #' par(mfrow=c(1,3))
@@ -51,38 +50,40 @@
 #'
 #' @export
 do.kudp <- function(X, ndim=2, type=c("proportion",0.1),
-                   preprocess=c("center","decorrelate","whiten"),
-                   kbandwidth=1.0){
+                   preprocess=c("center","scale","cscale","decorrelate","whiten"),
+                   bandwidth=1.0){
   #------------------------------------------------------------------------
   ## PREPROCESSING
   #   1. data matrix
   aux.typecheck(X)
   M = nrow(X)
   p = ncol(X)
+
   #   2. ndim
   ndim = as.integer(ndim)
   if (!check_ndim(ndim,p)){stop("* do.kudp : 'ndim' is a positive integer in [1,#(covariates)].")}
+
   #   3. preprocessing
   if (missing(preprocess)){
     algpreprocess = "center"
   } else {
     algpreprocess = match.arg(preprocess)
   }
-  tmplist = aux.preprocess(X,type=algpreprocess)
+  tmplist = aux.preprocess.hidden(X,type=algpreprocess,algtype="linear")
   trfinfo = tmplist$info
-  trfinfo$algtype = "linear"
   pX      = tmplist$pX
-  #   4. kernel-weights
-  kbandwidth = as.double(kbandwidth)
-  if (!check_NumMM(kbandwidth,0,1e+10,compact=TRUE)){stop("* do.kudp : 'kbandwidth' should be a nonnegative real number.")}
 
-  #   4. neighborhood creation
+  #   4. kernel-weights
+  bandwidth = as.double(bandwidth)
+  if (!check_NumMM(bandwidth,0,1e+10,compact=TRUE)){stop("* do.kudp : 'bandwidth' should be a nonnegative real number.")}
+
+  #   5. neighborhood creation
   nbdtype = type
   nbdsymmetric = "intersect"
   nbdstruct = aux.graphnbd(pX,method="euclidean",
                            type=nbdtype,symmetric=nbdsymmetric)
-  #   5. kernelized
-  K = exp(-(as.matrix(dist(pX))^2)/kbandwidth); diag(K) = 0; ## this part i'm not sure
+  #   6. kernelized
+  K = exp(-(as.matrix(dist(pX))^2)/bandwidth); diag(K) = 0; ## this part i'm not sure
   H = K*(nbdstruct$mask)
   D = diag(colSums(H))
   L = D-H                  # graph laplacian / local scatter kernel
