@@ -9,8 +9,7 @@
 #' @param X an \eqn{(n\times p)} matrix or data frame whose rows are observations
 #' @param ndim an integer-valued target dimension.
 #' @param preprocess  an additional option for preprocessing the data.
-#' Default is "center" and other options of "decorrelate" and "whiten"
-#' are supported. See also \code{\link{aux.preprocess}} for more details.
+#' Default is "center". See also \code{\link{aux.preprocess}} for more details.
 #' @param reltol tolerance level for stable computation of sparse reconstruction weights.
 #'
 #' @return a named list containing
@@ -42,7 +41,7 @@
 #' @author Kisung You
 #' @rdname linear_SPP
 #' @export
-do.spp <- function(X, ndim=2, preprocess = c("center","decorrelate","whiten"), reltol=1e-4){
+do.spp <- function(X, ndim=2, preprocess = c("center","scale","cscale","decorrelate","whiten"), reltol=1e-4){
   #------------------------------------------------------------------------
   ## PREPROCESSING
   #   1. data matrix
@@ -64,10 +63,9 @@ do.spp <- function(X, ndim=2, preprocess = c("center","decorrelate","whiten"), r
 
   #------------------------------------------------------------------------
   ## COMPUTATION PART 1 : PREPROCESSING
-  tmplist = aux.preprocess(X,type=algpreprocess)
+  tmplist = aux.preprocess.hidden(X,type=algpreprocess,algtype="linear")
   trfinfo = tmplist$info
   pX      = tmplist$pX
-  trfinfo$algtype = "linear"
 
   #------------------------------------------------------------------------
   ## COMPUTATION PART 2 : Main SPP : use CVXR
